====================
Administration Guide
====================

The OpenStack Dashboard is a web-based interface that allows you to
manage OpenStack resources and services. The Dashboard allows you to
interact with the OpenStack Compute cloud controller using the OpenStack
APIs. For more information about installing and configuring the
Dashboard, see the :doc:`/install/index` for your operating system.

.. toctree::
   :maxdepth: 2

   customize-configure.rst
   sessions.rst
   manage-images.rst
   admin-manage-roles.rst
   manage-projects-and-users.rst
   manage-instances.rst
   manage-flavors.rst
   manage-volumes.rst
   manage-shares.rst
   set-quotas.rst
   manage-services.rst
   manage-host-aggregates.rst

- To deploy the dashboard, see the :doc:`/install/index`.
- To launch instances with the dashboard as an end user, see the
  :doc:`/user/launch-instances` in the OpenStack End User Guide.
- To create and manage ports, see the :doc:`/user/create-networks`
  section of the OpenStack End User Guide.
